@@ -230,7 +230,7 @@ dynamic_MenuitemBuildvariantSlotT ::
 dynamic_MenuitemBuildvariantSlotT __funPtr mi properties = liftIO $ do
     mi' <- unsafeManagedPtrCastPtr mi
     maybeProperties <- case properties of
-        Nothing -> return nullPtr
+        Nothing -> return FP.nullPtr
         Just jProperties -> do
             jProperties' <- textToCString jProperties
             return jProperties'
@@ -274,7 +274,7 @@ wrap_MenuitemBuildvariantSlotT ::
 wrap_MenuitemBuildvariantSlotT gi'funptrptr gi'cb mi properties = do
     mi' <- (newObject Dbusmenu.Menuitem.Menuitem) mi
     maybeProperties <-
-        if properties == nullPtr
+        if properties == FP.nullPtr
         then return Nothing
         else do
             properties' <- cstringToText properties
